@@ -2,13 +2,23 @@ parJagsModel <-
 function(cl, name, file, data = sys.frame(sys.parent()), 
 inits, n.chains = 1, n.adapt = 1000, quiet = FALSE) 
 {
+    if (!suppressWarnings(require(rjags)))
+        stop("there is no package called 'rjags'")
+    ## stop if rjags not found
+    if (!suppressWarnings(require(rjags)))
+        stop("there is no package called 'rjags'")
+    cl <- evalParallelArgument(cl, quit=TRUE)
+    if (!inherits(cl, "cluster"))
+        stop("cl must be of class 'cluster'")
     if (length(cl) != n.chains)
         stop("length(cl) must equal n.chains")
     if (is.function(file) || inherits(file, "custommodel")) {
         if (is.function(file))
             file <- match.fun(file)
-        file <- write.jags.model(file)
-        on.exit(try(clean.jags.model(file)))
+        if (inherits(cl, "SOCKcluster")) {
+            file <- write.jags.model(file)
+            on.exit(try(clean.jags.model(file)))
+        }
     }
     n.clones <- dclone:::nclones.list(as.list(data))
     ## inits and RNGs
@@ -23,8 +33,10 @@ inits, n.chains = 1, n.adapt = 1000, quiet = FALSE)
         parallel.inits(n.chains=n.chains) else parallel.inits(inits, n.chains)
 #    inits <- jags.model(file, data, inits, n.chains, 
 #        n.adapt = 0)$state(internal = TRUE)
+    if (!is.character(name))
+        name <- as.character(name) # deparse(substitute(name))
     cldata <- list(file=file, data=as.list(data), inits=inits,
-        n.adapt=n.adapt, name=deparse(substitute(name)), quiet=quiet,
+        n.adapt=n.adapt, name=name, quiet=quiet,
         n.clones=n.clones)
     jagsparallel <- function(i) {
         cldata <- as.list(get(".DcloneEnv", envir=.GlobalEnv))
