@@ -1,7 +1,7 @@
 .onAttach <- function(libname, pkgname){
     ver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname), 
         fields=c("Version", "Date"))
-    packageStartupMessage(paste(pkgname, ver[1], "\t", ver[2], "\n"))
+    packageStartupMessage(paste(pkgname, ver[1], "\t", ver[2]))
     invisible(NULL)
 }
 
@@ -16,9 +16,6 @@
             "RNG"="none",
             "rhat"=1.1,
             "verbose"=1))
-    rj <- suppressWarnings(require(rjags))
-    if (!rj)
-        cat("Warning message:\n  there is no package called 'rjags'\n")
     invisible(NULL)
 }
 
